@@ -43,7 +43,7 @@ static void dirty_cb (GtkWidget *widget);
 static GtkWidget*
 create_table (void)
 {
-  GtkWidget *table, *vbox, *hbox,  *alignment, *label;
+  GtkWidget *vbox, *hbox,  *alignment, *label;
 
   remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   gsm_atk_set_description (remove_button, _("Remove the currently selected client from the session."));
@@ -84,8 +84,6 @@ create_table (void)
   gtk_box_pack_start (GTK_BOX (hbox), remove_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), apply_button, FALSE, FALSE, 0);
   
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
   label = gtk_label_new_with_mnemonic (_("Currently running _programs:"));
   gtk_container_add (GTK_CONTAINER (alignment), label);
@@ -93,6 +91,8 @@ create_table (void)
   
   gtk_box_pack_start (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
 
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), client_list);
 
   return vbox;
